( cd usr/include/asm-arm ; rm -rf arch )
( cd usr/include/asm-arm ; ln -sf arch-rpc arch )
( cd usr/include/asm-arm ; rm -rf proc )
( cd usr/include/asm-arm ; ln -sf proc-armv proc )
( cd usr/include ; rm -rf asm )
( cd usr/include ; ln -sf asm-arm asm )
