/*
 * This file is automatically generated from arch/arm/tools/getconstants.c.
 * Do not edit!  Only include this file in assembly (.S) files!
 */

#define TSK_SIGPENDING 8
#define TSK_ADDR_LIMIT 12
#define TSK_NEED_RESCHED 20
#define TSK_PTRACE 24
#define TSK_USED_MATH 572
#define TSS_SAVE 792
#define TSS_FPESAVE 632
#define TSS_DOMAIN 796
#define HPTE_TYPE_SMALL 2
#define HPTE_AP_READ 2720
#define HPTE_AP_WRITE 1360
#define LPTE_PRESENT 1
#define LPTE_YOUNG 2
#define LPTE_BUFFERABLE 4
#define LPTE_CACHEABLE 8
#define LPTE_USER 16
#define LPTE_WRITE 32
#define LPTE_EXEC 64
#define LPTE_DIRTY 128
#define PAGE_SZ 4096
#define SYS_ERROR0 10420224
