/*
 * Automatically generated by make menuconfig: don't edit
 */
#define AUTOCONF_INCLUDED
#define CONFIG_ARM 1
#undef  CONFIG_EISA
#undef  CONFIG_SBUS
#undef  CONFIG_MCA
#define CONFIG_UID16 1
#define CONFIG_RWSEM_GENERIC_SPINLOCK 1
#undef  CONFIG_RWSEM_XCHGADD_ALGORITHM
#undef  CONFIG_GENERIC_BUST_SPINLOCK
#undef  CONFIG_GENERIC_ISA_DMA

/*
 * Code maturity level options
 */
#define CONFIG_EXPERIMENTAL 1
#undef  CONFIG_OBSOLETE

/*
 * Loadable module support
 */
#define CONFIG_MODULES 1
#undef  CONFIG_MODVERSIONS
#define CONFIG_KMOD 1

/*
 * System Type
 */
#undef  CONFIG_ARCH_ANAKIN
#undef  CONFIG_ARCH_ARCA5K
#undef  CONFIG_ARCH_CLPS7500
#undef  CONFIG_ARCH_CLPS711X
#undef  CONFIG_ARCH_CO285
#undef  CONFIG_ARCH_EBSA110
#undef  CONFIG_ARCH_CAMELOT
#undef  CONFIG_ARCH_FOOTBRIDGE
#undef  CONFIG_ARCH_INTEGRATOR
#undef  CONFIG_ARCH_OMAHA
#undef  CONFIG_ARCH_L7200
#undef  CONFIG_ARCH_MX1ADS
#define CONFIG_ARCH_RPC 1
#undef  CONFIG_ARCH_RISCSTATION
#undef  CONFIG_ARCH_SA1100
#undef  CONFIG_ARCH_SHARK
#undef  CONFIG_ARCH_AT91RM9200

/*
 * Archimedes/A5000 Implementations
 */
#undef  CONFIG_ARCH_ARC
#undef  CONFIG_ARCH_A5K

/*
 * Footbridge Implementations
 */
#undef  CONFIG_ARCH_CATS
#undef  CONFIG_ARCH_PERSONAL_SERVER
#undef  CONFIG_ARCH_EBSA285_ADDIN
#undef  CONFIG_ARCH_EBSA285_HOST
#undef  CONFIG_ARCH_NETWINDER

/*
 * SA11x0 Implementations
 */
#undef  CONFIG_SA1100_ACCELENT
#undef  CONFIG_SA1100_ASSABET
#undef  CONFIG_ASSABET_NEPONSET
#undef  CONFIG_SA1100_ADSAGC
#undef  CONFIG_SA1100_ADSBITSY
#undef  CONFIG_SA1100_ADSBITSYPLUS
#undef  CONFIG_SA1100_BRUTUS
#undef  CONFIG_SA1100_CEP
#undef  CONFIG_SA1100_CERF
#undef  CONFIG_SA1100_H3100
#undef  CONFIG_SA1100_H3600
#undef  CONFIG_SA1100_H3800
#undef  CONFIG_SA1100_H3XXX
#undef  CONFIG_H3600_SLEEVE
#undef  CONFIG_SA1100_EXTENEX1
#undef  CONFIG_SA1100_FLEXANET
#undef  CONFIG_SA1100_FREEBIRD
#undef  CONFIG_SA1100_FRODO
#undef  CONFIG_SA1100_GRAPHICSCLIENT
#undef  CONFIG_SA1100_GRAPHICSMASTER
#undef  CONFIG_SA1100_HACKKIT
#undef  CONFIG_SA1100_BADGE4
#undef  CONFIG_SA1100_JORNADA720
#undef  CONFIG_SA1100_HUW_WEBPANEL
#undef  CONFIG_SA1100_ITSY
#undef  CONFIG_SA1100_LART
#undef  CONFIG_SA1100_NANOENGINE
#undef  CONFIG_SA1100_OMNIMETER
#undef  CONFIG_SA1100_PANGOLIN
#undef  CONFIG_SA1100_PLEB
#undef  CONFIG_SA1100_PT_SYSTEM3
#undef  CONFIG_SA1100_SHANNON
#undef  CONFIG_SA1100_SHERMAN
#undef  CONFIG_SA1100_SIMPAD
#undef  CONFIG_SA1100_SIMPUTER
#undef  CONFIG_SA1100_PFS168
#undef  CONFIG_SA1100_VICTOR
#undef  CONFIG_SA1100_XP860
#undef  CONFIG_SA1100_YOPY
#undef  CONFIG_SA1100_USB
#undef  CONFIG_SA1100_USB_NETLINK
#undef  CONFIG_SA1100_USB_CHAR
#undef  CONFIG_SA1100_SSP

/*
 * AT91RM9200 Implementations
 */
#undef  CONFIG_ARCH_AT91RM9200DK
#undef  CONFIG_MACH_CSB337

/*
 * CLPS711X/EP721X Implementations
 */
#undef  CONFIG_ARCH_AUTCPU12
#undef  CONFIG_ARCH_CDB89712
#undef  CONFIG_ARCH_CLEP7312
#undef  CONFIG_ARCH_EDB7211
#undef  CONFIG_ARCH_FORTUNET
#undef  CONFIG_ARCH_GUIDEA07
#undef  CONFIG_ARCH_P720T
#undef  CONFIG_ARCH_EP7211
#undef  CONFIG_ARCH_EP7212
#define CONFIG_ARCH_ACORN 1
#undef  CONFIG_PLD
#undef  CONFIG_FOOTBRIDGE
#undef  CONFIG_FOOTBRIDGE_HOST
#undef  CONFIG_FOOTBRIDGE_ADDIN
#define CONFIG_CPU_32 1
#undef  CONFIG_CPU_26
#undef  CONFIG_CPU_ARM610
#undef  CONFIG_CPU_ARM710
#undef  CONFIG_CPU_ARM720T
#undef  CONFIG_CPU_ARM920T
#undef  CONFIG_CPU_ARM922T
#undef  CONFIG_CPU_ARM926T
#undef  CONFIG_CPU_ARM1020
#undef  CONFIG_CPU_ARM1020E
#undef  CONFIG_CPU_ARM1022
#undef  CONFIG_CPU_ARM1026
#define CONFIG_CPU_SA110 1
#undef  CONFIG_CPU_SA1100
#define CONFIG_CPU_32v3 1
#undef  CONFIG_CPU_32v4
#undef  CONFIG_DISCONTIGMEM

/*
 * General setup
 */
#undef  CONFIG_PCI
#undef  CONFIG_ISA
#undef  CONFIG_ISA_DMA
#undef  CONFIG_ZBOOT_ROM
#define CONFIG_ZBOOT_ROM_TEXT 0x0
#define CONFIG_ZBOOT_ROM_BSS 0x0
#undef  CONFIG_HOTPLUG
#undef  CONFIG_PCMCIA
#define CONFIG_NET 1
#define CONFIG_SYSVIPC 1
#undef  CONFIG_BSD_PROCESS_ACCT
#define CONFIG_SYSCTL 1
#undef  CONFIG_FPE_NWFPE
#define CONFIG_FPE_FASTFPE 1
#define CONFIG_KCORE_ELF 1
#undef  CONFIG_KCORE_AOUT
#define CONFIG_BINFMT_AOUT 1
#define CONFIG_BINFMT_ELF 1
#undef  CONFIG_BINFMT_MISC
#undef  CONFIG_PM
#undef  CONFIG_ARTHUR
#define CONFIG_CMDLINE "root=1f04"
#define CONFIG_ALIGNMENT_TRAP 1

/*
 * Parallel port support
 */
#define CONFIG_PARPORT 1
#define CONFIG_PARPORT_PC 1
#define CONFIG_PARPORT_PC_CML1 1
#undef  CONFIG_PARPORT_SERIAL
#define CONFIG_PARPORT_PC_FIFO 1
#undef  CONFIG_PARPORT_PC_SUPERIO
#undef  CONFIG_PARPORT_PC_PCMCIA
#undef  CONFIG_PARPORT_ARC
#undef  CONFIG_PARPORT_IDP
#undef  CONFIG_PARPORT_AMIGA
#undef  CONFIG_PARPORT_MFC3
#undef  CONFIG_PARPORT_ATARI
#undef  CONFIG_PARPORT_GSC
#undef  CONFIG_PARPORT_SUNBPP
#undef  CONFIG_PARPORT_IP22
#undef  CONFIG_PARPORT_OTHER
#undef  CONFIG_PARPORT_1284

/*
 * Memory Technology Devices (MTD)
 */
#undef  CONFIG_MTD

/*
 * Plug and Play configuration
 */
#undef  CONFIG_PNP
#undef  CONFIG_ISAPNP

/*
 * Block devices
 */
#define CONFIG_BLK_DEV_FD 1
#undef  CONFIG_BLK_DEV_XD
#undef  CONFIG_PARIDE
#undef  CONFIG_BLK_CPQ_DA
#undef  CONFIG_BLK_CPQ_CISS_DA
#undef  CONFIG_CISS_SCSI_TAPE
#undef  CONFIG_CISS_MONITOR_THREAD
#undef  CONFIG_BLK_DEV_DAC960
#undef  CONFIG_BLK_DEV_UMEM
#define CONFIG_BLK_DEV_LOOP 1
#undef  CONFIG_BLK_DEV_NBD
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_BLK_DEV_RAM_SIZE (8192)
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_BLK_STATS 1

/*
 * Multi-device support (RAID and LVM)
 */
#undef  CONFIG_MD
#undef  CONFIG_BLK_DEV_MD
#undef  CONFIG_MD_LINEAR
#undef  CONFIG_MD_RAID0
#undef  CONFIG_MD_RAID1
#undef  CONFIG_MD_RAID5
#undef  CONFIG_MD_MULTIPATH
#undef  CONFIG_BLK_DEV_LVM

/*
 * Acorn-specific block devices
 */

/*
 * Networking options
 */
#define CONFIG_PACKET 1
#undef  CONFIG_PACKET_MMAP
#undef  CONFIG_NETLINK_DEV
#define CONFIG_NETFILTER 1
#undef  CONFIG_NETFILTER_DEBUG
#define CONFIG_FILTER 1
#define CONFIG_UNIX 1
#define CONFIG_INET 1
#define CONFIG_IP_MULTICAST 1
#undef  CONFIG_IP_ADVANCED_ROUTER
#define CONFIG_IP_PNP 1
#undef  CONFIG_IP_PNP_DHCP
#undef  CONFIG_IP_PNP_BOOTP
#undef  CONFIG_IP_PNP_RARP
#undef  CONFIG_NET_IPIP
#undef  CONFIG_NET_IPGRE
#undef  CONFIG_IP_MROUTE
#undef  CONFIG_ARPD
#undef  CONFIG_INET_ECN
#undef  CONFIG_SYN_COOKIES

/*
 *   IP: Netfilter Configuration
 */
#undef  CONFIG_IP_NF_CONNTRACK
#define CONFIG_IP_NF_CONNTRACK_MODULE 1
#undef  CONFIG_IP_NF_FTP
#define CONFIG_IP_NF_FTP_MODULE 1
#undef  CONFIG_IP_NF_AMANDA
#define CONFIG_IP_NF_AMANDA_MODULE 1
#undef  CONFIG_IP_NF_TFTP
#define CONFIG_IP_NF_TFTP_MODULE 1
#undef  CONFIG_IP_NF_IRC
#define CONFIG_IP_NF_IRC_MODULE 1
#undef  CONFIG_IP_NF_QUEUE
#define CONFIG_IP_NF_IPTABLES 1
#undef  CONFIG_IP_NF_MATCH_LIMIT
#define CONFIG_IP_NF_MATCH_LIMIT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MAC
#define CONFIG_IP_NF_MATCH_MAC_MODULE 1
#undef  CONFIG_IP_NF_MATCH_PKTTYPE
#define CONFIG_IP_NF_MATCH_PKTTYPE_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MARK
#define CONFIG_IP_NF_MATCH_MARK_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MULTIPORT
#define CONFIG_IP_NF_MATCH_MULTIPORT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TOS
#define CONFIG_IP_NF_MATCH_TOS_MODULE 1
#undef  CONFIG_IP_NF_MATCH_RECENT
#define CONFIG_IP_NF_MATCH_RECENT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_ECN
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#undef  CONFIG_IP_NF_MATCH_DSCP
#define CONFIG_IP_NF_MATCH_DSCP_MODULE 1
#undef  CONFIG_IP_NF_MATCH_AH_ESP
#define CONFIG_IP_NF_MATCH_AH_ESP_MODULE 1
#undef  CONFIG_IP_NF_MATCH_LENGTH
#define CONFIG_IP_NF_MATCH_LENGTH_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TTL
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TCPMSS
#define CONFIG_IP_NF_MATCH_TCPMSS_MODULE 1
#undef  CONFIG_IP_NF_MATCH_HELPER
#define CONFIG_IP_NF_MATCH_HELPER_MODULE 1
#undef  CONFIG_IP_NF_MATCH_STATE
#define CONFIG_IP_NF_MATCH_STATE_MODULE 1
#undef  CONFIG_IP_NF_MATCH_CONNTRACK
#define CONFIG_IP_NF_MATCH_CONNTRACK_MODULE 1
#undef  CONFIG_IP_NF_MATCH_UNCLEAN
#define CONFIG_IP_NF_MATCH_UNCLEAN_MODULE 1
#undef  CONFIG_IP_NF_MATCH_OWNER
#define CONFIG_IP_NF_MATCH_OWNER_MODULE 1
#undef  CONFIG_IP_NF_FILTER
#define CONFIG_IP_NF_FILTER_MODULE 1
#undef  CONFIG_IP_NF_TARGET_REJECT
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#undef  CONFIG_IP_NF_TARGET_MIRROR
#define CONFIG_IP_NF_TARGET_MIRROR_MODULE 1
#undef  CONFIG_IP_NF_NAT
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_IP_NF_NAT_NEEDED 1
#undef  CONFIG_IP_NF_TARGET_MASQUERADE
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#undef  CONFIG_IP_NF_TARGET_REDIRECT
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#undef  CONFIG_IP_NF_NAT_AMANDA
#define CONFIG_IP_NF_NAT_AMANDA_MODULE 1
#undef  CONFIG_IP_NF_NAT_LOCAL
#undef  CONFIG_IP_NF_NAT_SNMP_BASIC
#undef  CONFIG_IP_NF_NAT_IRC
#define CONFIG_IP_NF_NAT_IRC_MODULE 1
#undef  CONFIG_IP_NF_NAT_FTP
#define CONFIG_IP_NF_NAT_FTP_MODULE 1
#undef  CONFIG_IP_NF_NAT_TFTP
#define CONFIG_IP_NF_NAT_TFTP_MODULE 1
#undef  CONFIG_IP_NF_MANGLE
#define CONFIG_IP_NF_MANGLE_MODULE 1
#undef  CONFIG_IP_NF_TARGET_TOS
#define CONFIG_IP_NF_TARGET_TOS_MODULE 1
#undef  CONFIG_IP_NF_TARGET_ECN
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#undef  CONFIG_IP_NF_TARGET_DSCP
#define CONFIG_IP_NF_TARGET_DSCP_MODULE 1
#undef  CONFIG_IP_NF_TARGET_MARK
#define CONFIG_IP_NF_TARGET_MARK_MODULE 1
#undef  CONFIG_IP_NF_TARGET_LOG
#define CONFIG_IP_NF_TARGET_LOG_MODULE 1
#undef  CONFIG_IP_NF_TARGET_ULOG
#define CONFIG_IP_NF_TARGET_ULOG_MODULE 1
#undef  CONFIG_IP_NF_TARGET_TCPMSS
#define CONFIG_IP_NF_TARGET_TCPMSS_MODULE 1
#undef  CONFIG_IP_NF_ARPTABLES
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#undef  CONFIG_IP_NF_ARPFILTER
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#undef  CONFIG_IP_NF_ARP_MANGLE
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1

/*
 *   IP: Virtual Server Configuration
 */
#undef  CONFIG_IP_VS
#undef  CONFIG_IPV6
#undef  CONFIG_KHTTPD

/*
 *    SCTP Configuration (EXPERIMENTAL)
 */
#undef  CONFIG_IP_SCTP
#undef  CONFIG_ATM
#undef  CONFIG_VLAN_8021Q
#undef  CONFIG_IPX
#undef  CONFIG_ATALK

/*
 * Appletalk devices
 */
#undef  CONFIG_DEV_APPLETALK
#undef  CONFIG_DECNET
#undef  CONFIG_BRIDGE
#undef  CONFIG_X25
#undef  CONFIG_LAPB
#undef  CONFIG_LLC
#undef  CONFIG_NET_DIVERT
#undef  CONFIG_ECONET
#define CONFIG_ECONET_MODULE 1
#undef  CONFIG_ECONET_AUNUDP
#define CONFIG_ECONET_NATIVE 1
#undef  CONFIG_WAN_ROUTER
#undef  CONFIG_NET_FASTROUTE
#undef  CONFIG_NET_HW_FLOWCONTROL

/*
 * QoS and/or fair queueing
 */
#undef  CONFIG_NET_SCHED

/*
 * Network testing
 */
#undef  CONFIG_NET_PKTGEN

/*
 * Network device support
 */
#define CONFIG_NETDEVICES 1

/*
 * ARCnet devices
 */
#undef  CONFIG_ARCNET
#undef  CONFIG_DUMMY
#undef  CONFIG_BONDING
#undef  CONFIG_EQUALIZER
#undef  CONFIG_TUN
#undef  CONFIG_ETHERTAP

/*
 * Ethernet (10 or 100Mbit)
 */
#define CONFIG_NET_ETHERNET 1
#undef  CONFIG_ARM_AM79C961A
#undef  CONFIG_ARM_CIRRUS
#define CONFIG_ARM_ETHER1 1
#define CONFIG_ARM_ETHER3 1
#define CONFIG_ARM_ETHERH 1
#undef  CONFIG_SUNLANCE
#undef  CONFIG_SUNBMAC
#undef  CONFIG_SUNQE
#undef  CONFIG_SUNGEM
#undef  CONFIG_NET_VENDOR_3COM
#undef  CONFIG_LANCE
#undef  CONFIG_NET_VENDOR_SMC
#undef  CONFIG_NET_VENDOR_RACAL
#undef  CONFIG_NET_ISA
#undef  CONFIG_NET_PCI
#undef  CONFIG_NET_POCKET

/*
 * Ethernet (1000 Mbit)
 */
#undef  CONFIG_ACENIC
#undef  CONFIG_DL2K
#undef  CONFIG_E1000
#undef  CONFIG_MYRI_SBUS
#undef  CONFIG_NS83820
#undef  CONFIG_HAMACHI
#undef  CONFIG_YELLOWFIN
#undef  CONFIG_R8169
#undef  CONFIG_SK98LIN
#undef  CONFIG_TIGON3
#undef  CONFIG_FDDI
#undef  CONFIG_HIPPI
#undef  CONFIG_PLIP
#define CONFIG_PPP 1
#undef  CONFIG_PPP_MULTILINK
#undef  CONFIG_PPP_FILTER
#undef  CONFIG_PPP_ASYNC
#undef  CONFIG_PPP_SYNC_TTY
#define CONFIG_PPP_DEFLATE 1
#define CONFIG_PPP_BSDCOMP 1
#undef  CONFIG_PPPOE
#undef  CONFIG_SLIP

/*
 * Wireless LAN (non-hamradio)
 */
#undef  CONFIG_NET_RADIO

/*
 * Token Ring devices
 */
#undef  CONFIG_TR
#undef  CONFIG_NET_FC
#undef  CONFIG_RCPCI
#undef  CONFIG_SHAPER

/*
 * Wan interfaces
 */
#undef  CONFIG_WAN

/*
 * Amateur Radio support
 */
#undef  CONFIG_HAMRADIO

/*
 * IrDA (infrared) support
 */
#undef  CONFIG_IRDA

/*
 * ATA/ATAPI/MFM/RLL support
 */
#define CONFIG_IDE 1

/*
 * IDE, ATA and ATAPI Block devices
 */
#define CONFIG_BLK_DEV_IDE 1
#undef  CONFIG_BLK_DEV_HD_IDE
#undef  CONFIG_BLK_DEV_HD
#define CONFIG_BLK_DEV_IDEDISK 1
#define CONFIG_IDEDISK_MULTI_MODE 1
#undef  CONFIG_IDEDISK_STROKE
#undef  CONFIG_BLK_DEV_IDECS
#define CONFIG_BLK_DEV_IDECD 1
#undef  CONFIG_BLK_DEV_IDETAPE
#undef  CONFIG_BLK_DEV_IDEFLOPPY
#define CONFIG_BLK_DEV_IDESCSI 1
#undef  CONFIG_IDE_TASK_IOCTL
#undef  CONFIG_BLK_DEV_CMD640
#undef  CONFIG_BLK_DEV_CMD640_ENHANCED
#undef  CONFIG_BLK_DEV_ISAPNP
#define CONFIG_BLK_DEV_IDE_ICSIDE 1
#define CONFIG_BLK_DEV_IDEDMA_ICS 1
#define CONFIG_IDEDMA_ICS_AUTO 1
#define CONFIG_BLK_DEV_IDEDMA 1
#define CONFIG_BLK_DEV_IDE_RAPIDE 1
#undef  CONFIG_IDE_CHIPSETS
#define CONFIG_IDEDMA_AUTO 1
#undef  CONFIG_IDEDMA_IVB
#undef  CONFIG_DMA_NONPCI
#undef  CONFIG_BLK_DEV_ATARAID
#undef  CONFIG_BLK_DEV_ATARAID_PDC
#undef  CONFIG_BLK_DEV_ATARAID_HPT
#undef  CONFIG_BLK_DEV_ATARAID_MEDLEY
#undef  CONFIG_BLK_DEV_ATARAID_SII

/*
 * SCSI support
 */
#define CONFIG_SCSI 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_SD_EXTRA_DEVS (8)
#define CONFIG_CHR_DEV_ST 1
#undef  CONFIG_CHR_DEV_OSST
#define CONFIG_BLK_DEV_SR 1
#define CONFIG_BLK_DEV_SR_VENDOR 1
#define CONFIG_SR_EXTRA_DEVS (2)
#define CONFIG_CHR_DEV_SG 1
#define CONFIG_SCSI_DEBUG_QUEUES 1
#undef  CONFIG_SCSI_MULTI_LUN
#define CONFIG_SCSI_CONSTANTS 1
#define CONFIG_SCSI_LOGGING 1

/*
 * SCSI low-level drivers
 */
#undef  CONFIG_SCSI_7000FASST
#undef  CONFIG_SCSI_ACARD
#undef  CONFIG_SCSI_AHA152X
#undef  CONFIG_SCSI_AHA1542
#undef  CONFIG_SCSI_AHA1740
#undef  CONFIG_SCSI_AACRAID
#undef  CONFIG_SCSI_AIC7XXX
#undef  CONFIG_SCSI_AIC79XX
#undef  CONFIG_SCSI_AIC7XXX_OLD
#undef  CONFIG_SCSI_DPT_I2O
#undef  CONFIG_SCSI_ADVANSYS
#undef  CONFIG_SCSI_IN2000
#undef  CONFIG_SCSI_AM53C974
#undef  CONFIG_SCSI_MEGARAID
#undef  CONFIG_SCSI_MEGARAID2
#undef  CONFIG_SCSI_BUSLOGIC
#undef  CONFIG_SCSI_DMX3191D
#undef  CONFIG_SCSI_DTC3280
#undef  CONFIG_SCSI_EATA
#undef  CONFIG_SCSI_EATA_DMA
#undef  CONFIG_SCSI_EATA_PIO
#undef  CONFIG_SCSI_FUTURE_DOMAIN
#undef  CONFIG_SCSI_GDTH
#undef  CONFIG_SCSI_GENERIC_NCR5380
#undef  CONFIG_SCSI_INITIO
#undef  CONFIG_SCSI_INIA100
#undef  CONFIG_SCSI_PPA
#undef  CONFIG_SCSI_IMM
#undef  CONFIG_SCSI_NCR53C406A
#undef  CONFIG_SCSI_NCR53C7xx
#undef  CONFIG_SCSI_PAS16
#undef  CONFIG_SCSI_PCI2000
#undef  CONFIG_SCSI_PCI2220I
#undef  CONFIG_SCSI_PSI240I
#undef  CONFIG_SCSI_QLOGIC_FAS
#undef  CONFIG_SCSI_SIM710
#undef  CONFIG_SCSI_SYM53C416
#undef  CONFIG_SCSI_T128
#undef  CONFIG_SCSI_U14_34F
#undef  CONFIG_SCSI_NSP32
#undef  CONFIG_SCSI_DEBUG
#define CONFIG_SCSI_ACORNSCSI_3 1
#define CONFIG_SCSI_ACORNSCSI_TAGGED_QUEUE 1
#define CONFIG_SCSI_ACORNSCSI_SYNC 1
#define CONFIG_SCSI_ARXESCSI 1
#define CONFIG_SCSI_CUMANA_2 1
#define CONFIG_SCSI_EESOXSCSI 1
#define CONFIG_SCSI_POWERTECSCSI 1
#undef  CONFIG_SCSI_CUMANA_1
#undef  CONFIG_SCSI_OAK1

/*
 * I2O device support
 */
#undef  CONFIG_I2O
#undef  CONFIG_I2O_BLOCK
#undef  CONFIG_I2O_LAN
#undef  CONFIG_I2O_SCSI
#undef  CONFIG_I2O_PROC

/*
 * ISDN subsystem
 */
#undef  CONFIG_ISDN

/*
 * Input core support
 */
#undef  CONFIG_INPUT
#undef  CONFIG_INPUT_KEYBDEV
#undef  CONFIG_INPUT_MOUSEDEV
#undef  CONFIG_INPUT_JOYDEV
#undef  CONFIG_INPUT_EVDEV
#undef  CONFIG_INPUT_UINPUT
#undef  CONFIG_INPUT_MX1TS

/*
 * Character devices
 */
#define CONFIG_VT 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_SERIAL 1
#define CONFIG_SERIAL_CONSOLE 1
#define CONFIG_ATOMWIDE_SERIAL 1
#define CONFIG_DUALSP_SERIAL 1
#define CONFIG_SERIAL_EXTENDED 1
#undef  CONFIG_SERIAL_MANY_PORTS
#define CONFIG_SERIAL_SHARE_IRQ 1
#undef  CONFIG_SERIAL_DETECT_IRQ
#undef  CONFIG_SERIAL_MULTIPORT
#undef  CONFIG_HUB6
#undef  CONFIG_SERIAL_NONSTANDARD

/*
 * Serial drivers
 */
#undef  CONFIG_SERIAL_ANAKIN
#undef  CONFIG_SERIAL_ANAKIN_CONSOLE
#undef  CONFIG_SERIAL_AMBA
#undef  CONFIG_SERIAL_AMBA_CONSOLE
#undef  CONFIG_SERIAL_CLPS711X
#undef  CONFIG_SERIAL_CLPS711X_CONSOLE
#undef  CONFIG_SERIAL_21285
#undef  CONFIG_SERIAL_21285_OLD
#undef  CONFIG_SERIAL_21285_CONSOLE
#undef  CONFIG_SERIAL_UART00
#undef  CONFIG_SERIAL_UART00_CONSOLE
#undef  CONFIG_SERIAL_SA1100
#undef  CONFIG_SERIAL_SA1100_CONSOLE
#undef  CONFIG_SERIAL_OMAHA
#undef  CONFIG_SERIAL_OMAHA_CONSOLE
#undef  CONFIG_SERIAL_AT91
#undef  CONFIG_SERIAL_AT91_CONSOLE
#undef  CONFIG_SERIAL_8250
#undef  CONFIG_SERIAL_8250_CONSOLE
#undef  CONFIG_SERIAL_8250_EXTENDED
#undef  CONFIG_SERIAL_8250_MANY_PORTS
#undef  CONFIG_SERIAL_8250_SHARE_IRQ
#undef  CONFIG_SERIAL_8250_DETECT_IRQ
#undef  CONFIG_SERIAL_8250_MULTIPORT
#undef  CONFIG_SERIAL_8250_HUB6
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_UNIX98_PTY_COUNT (256)
#define CONFIG_PRINTER 1
#undef  CONFIG_LP_CONSOLE
#undef  CONFIG_PPDEV
#undef  CONFIG_TIPAR

/*
 * I2C support
 */
#define CONFIG_I2C 1
#define CONFIG_I2C_ALGOBIT 1
#undef  CONFIG_I2C_PHILIPSPAR
#undef  CONFIG_I2C_ELV
#undef  CONFIG_I2C_VELLEMAN
#undef  CONFIG_SCx200_I2C
#undef  CONFIG_I2C_GUIDE
#undef  CONFIG_SCx200_ACB
#undef  CONFIG_I2C_ALGOPCF
#define CONFIG_I2C_CHARDEV 1
#undef  CONFIG_I2C_PROC
#undef  CONFIG_I2C_DS1307

/*
 * L3 serial bus support
 */
#undef  CONFIG_L3
#undef  CONFIG_L3_ALGOBIT
#undef  CONFIG_L3_BIT_SA1100_GPIO
#undef  CONFIG_L3_SA1111
#undef  CONFIG_BIT_SA1100_GPIO

/*
 * Mice
 */
#define CONFIG_BUSMOUSE 1
#undef  CONFIG_ATIXL_BUSMOUSE
#undef  CONFIG_LOGIBUSMOUSE
#undef  CONFIG_MS_BUSMOUSE
#undef  CONFIG_MOUSE

/*
 * Joysticks
 */
#undef  CONFIG_INPUT_GAMEPORT
#undef  CONFIG_QIC02_TAPE
#undef  CONFIG_IPMI_HANDLER
#undef  CONFIG_IPMI_PANIC_EVENT
#undef  CONFIG_IPMI_DEVICE_INTERFACE
#undef  CONFIG_IPMI_KCS
#undef  CONFIG_IPMI_WATCHDOG

/*
 * Watchdog Cards
 */
#undef  CONFIG_WATCHDOG
#undef  CONFIG_SCx200
#undef  CONFIG_SCx200_GPIO
#undef  CONFIG_AMD_PM768
#undef  CONFIG_NVRAM
#undef  CONFIG_RTC
#undef  CONFIG_DTLK
#undef  CONFIG_R3964
#undef  CONFIG_APPLICOM

/*
 * Ftape, the floppy tape device driver
 */
#undef  CONFIG_FTAPE
#undef  CONFIG_AGP

/*
 * Direct Rendering Manager (XFree86 DRI support)
 */
#undef  CONFIG_DRM
#define CONFIG_RPCMOUSE 1

/*
 * Multimedia devices
 */
#undef  CONFIG_VIDEO_DEV

/*
 * File systems
 */
#undef  CONFIG_QUOTA
#undef  CONFIG_QFMT_V2
#undef  CONFIG_AUTOFS_FS
#define CONFIG_AUTOFS4_FS 1
#undef  CONFIG_REISERFS_FS
#undef  CONFIG_REISERFS_CHECK
#undef  CONFIG_REISERFS_PROC_INFO
#define CONFIG_ADFS_FS 1
#define CONFIG_ADFS_FS_RW 1
#undef  CONFIG_AFFS_FS
#undef  CONFIG_HFS_FS
#undef  CONFIG_HFSPLUS_FS
#undef  CONFIG_BEFS_FS
#undef  CONFIG_BEFS_DEBUG
#undef  CONFIG_BFS_FS
#define CONFIG_EXT3_FS 1
#define CONFIG_JBD 1
#undef  CONFIG_JBD_DEBUG
#define CONFIG_FAT_FS 1
#define CONFIG_MSDOS_FS 1
#undef  CONFIG_UMSDOS_FS
#define CONFIG_VFAT_FS 1
#undef  CONFIG_EFS_FS
#undef  CONFIG_JFFS_FS
#undef  CONFIG_JFFS2_FS
#undef  CONFIG_CRAMFS
#undef  CONFIG_TMPFS
#define CONFIG_RAMFS 1
#define CONFIG_ISO9660_FS 1
#define CONFIG_JOLIET 1
#undef  CONFIG_ZISOFS
#undef  CONFIG_JFS_FS
#undef  CONFIG_JFS_DEBUG
#undef  CONFIG_JFS_STATISTICS
#undef  CONFIG_MINIX_FS
#undef  CONFIG_VXFS_FS
#undef  CONFIG_NTFS_FS
#undef  CONFIG_NTFS_RW
#undef  CONFIG_HPFS_FS
#define CONFIG_PROC_FS 1
#undef  CONFIG_DEVFS_FS
#undef  CONFIG_DEVFS_MOUNT
#undef  CONFIG_DEVFS_DEBUG
#define CONFIG_DEVPTS_FS 1
#undef  CONFIG_QNX4FS_FS
#undef  CONFIG_QNX4FS_RW
#undef  CONFIG_ROMFS_FS
#define CONFIG_EXT2_FS 1
#undef  CONFIG_SYSV_FS
#define CONFIG_UDF_FS 1
#undef  CONFIG_UDF_RW
#undef  CONFIG_UFS_FS
#undef  CONFIG_UFS_FS_WRITE
#undef  CONFIG_XFS_FS
#undef  CONFIG_XFS_QUOTA
#undef  CONFIG_XFS_RT
#undef  CONFIG_XFS_TRACE
#undef  CONFIG_XFS_DEBUG

/*
 * Network File Systems
 */
#undef  CONFIG_CODA_FS
#undef  CONFIG_INTERMEZZO_FS
#define CONFIG_NFS_FS 1
#define CONFIG_NFS_V3 1
#undef  CONFIG_NFS_DIRECTIO
#define CONFIG_ROOT_NFS 1
#define CONFIG_NFSD 1
#define CONFIG_NFSD_V3 1
#define CONFIG_NFSD_TCP 1
#define CONFIG_SUNRPC 1
#define CONFIG_LOCKD 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_SMB_FS 1
#undef  CONFIG_SMB_NLS_DEFAULT
#undef  CONFIG_SMB_UNIX
#undef  CONFIG_NCP_FS
#undef  CONFIG_NCPFS_PACKET_SIGNING
#undef  CONFIG_NCPFS_IOCTL_LOCKING
#undef  CONFIG_NCPFS_STRONG
#undef  CONFIG_NCPFS_NFS_NS
#undef  CONFIG_NCPFS_OS2_NS
#undef  CONFIG_NCPFS_SMALLDOS
#undef  CONFIG_NCPFS_NLS
#undef  CONFIG_NCPFS_EXTRAS
#undef  CONFIG_ZISOFS_FS

/*
 * Partition Types
 */
#define CONFIG_PARTITION_ADVANCED 1
#define CONFIG_ACORN_PARTITION 1
#define CONFIG_ACORN_PARTITION_EESOX 1
#define CONFIG_ACORN_PARTITION_ICS 1
#define CONFIG_ACORN_PARTITION_ADFS 1
#define CONFIG_ACORN_PARTITION_POWERTEC 1
#define CONFIG_ACORN_PARTITION_RISCIX 1
#undef  CONFIG_OSF_PARTITION
#undef  CONFIG_AMIGA_PARTITION
#undef  CONFIG_ATARI_PARTITION
#undef  CONFIG_MAC_PARTITION
#define CONFIG_MSDOS_PARTITION 1
#undef  CONFIG_BSD_DISKLABEL
#undef  CONFIG_MINIX_SUBPARTITION
#undef  CONFIG_SOLARIS_X86_PARTITION
#undef  CONFIG_UNIXWARE_DISKLABEL
#undef  CONFIG_LDM_PARTITION
#undef  CONFIG_SGI_PARTITION
#undef  CONFIG_ULTRIX_PARTITION
#undef  CONFIG_SUN_PARTITION
#undef  CONFIG_EFI_PARTITION
#define CONFIG_SMB_NLS 1
#define CONFIG_NLS 1

/*
 * Native Language Support
 */
#define CONFIG_NLS_DEFAULT "iso8859-1"
#define CONFIG_NLS_CODEPAGE_437 1
#undef  CONFIG_NLS_CODEPAGE_737
#undef  CONFIG_NLS_CODEPAGE_775
#define CONFIG_NLS_CODEPAGE_850 1
#undef  CONFIG_NLS_CODEPAGE_852
#undef  CONFIG_NLS_CODEPAGE_855
#undef  CONFIG_NLS_CODEPAGE_857
#undef  CONFIG_NLS_CODEPAGE_860
#undef  CONFIG_NLS_CODEPAGE_861
#undef  CONFIG_NLS_CODEPAGE_862
#undef  CONFIG_NLS_CODEPAGE_863
#undef  CONFIG_NLS_CODEPAGE_864
#undef  CONFIG_NLS_CODEPAGE_865
#undef  CONFIG_NLS_CODEPAGE_866
#undef  CONFIG_NLS_CODEPAGE_869
#undef  CONFIG_NLS_CODEPAGE_936
#undef  CONFIG_NLS_CODEPAGE_950
#undef  CONFIG_NLS_CODEPAGE_932
#undef  CONFIG_NLS_CODEPAGE_949
#undef  CONFIG_NLS_CODEPAGE_874
#undef  CONFIG_NLS_ISO8859_8
#undef  CONFIG_NLS_CODEPAGE_1250
#undef  CONFIG_NLS_CODEPAGE_1251
#define CONFIG_NLS_ISO8859_1 1
#undef  CONFIG_NLS_ISO8859_2
#undef  CONFIG_NLS_ISO8859_3
#undef  CONFIG_NLS_ISO8859_4
#undef  CONFIG_NLS_ISO8859_5
#undef  CONFIG_NLS_ISO8859_6
#undef  CONFIG_NLS_ISO8859_7
#undef  CONFIG_NLS_ISO8859_9
#undef  CONFIG_NLS_ISO8859_13
#undef  CONFIG_NLS_ISO8859_14
#undef  CONFIG_NLS_ISO8859_15
#undef  CONFIG_NLS_KOI8_R
#undef  CONFIG_NLS_KOI8_U
#undef  CONFIG_NLS_UTF8

/*
 * Console drivers
 */

/*
 * Frame-buffer support
 */
#define CONFIG_FB 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_FB_ACORN 1
#undef  CONFIG_FB_ANAKIN
#undef  CONFIG_FB_CLPS711X
#undef  CONFIG_FB_SA1100
#undef  CONFIG_FB_DBMX1
#undef  CONFIG_FB_CYBER2000
#undef  CONFIG_FB_VIRTUAL
#define CONFIG_FBCON_ADVANCED 1
#define CONFIG_FBCON_MFB 1
#define CONFIG_FBCON_CFB2 1
#define CONFIG_FBCON_CFB4 1
#define CONFIG_FBCON_CFB8 1
#define CONFIG_FBCON_CFB16 1
#define CONFIG_FBCON_CFB24 1
#define CONFIG_FBCON_CFB32 1
#undef  CONFIG_FBCON_AFB
#undef  CONFIG_FBCON_ILBM
#undef  CONFIG_FBCON_IPLAN2P2
#undef  CONFIG_FBCON_IPLAN2P4
#undef  CONFIG_FBCON_IPLAN2P8
#undef  CONFIG_FBCON_MAC
#undef  CONFIG_FBCON_VGA_PLANES
#undef  CONFIG_FBCON_VGA
#undef  CONFIG_FBCON_HGA
#undef  CONFIG_FBCON_FONTWIDTH8_ONLY
#define CONFIG_FBCON_FONTS 1
#undef  CONFIG_FONT_8x8
#undef  CONFIG_FONT_8x16
#undef  CONFIG_FONT_SUN8x16
#undef  CONFIG_FONT_SUN12x22
#undef  CONFIG_FONT_6x11
#undef  CONFIG_FONT_PEARL_8x8
#define CONFIG_FONT_ACORN_8x8 1

/*
 * Sound
 */
#define CONFIG_SOUND 1
#undef  CONFIG_SOUND_ALI5455
#undef  CONFIG_SOUND_BT878
#undef  CONFIG_SOUND_CMPCI
#undef  CONFIG_SOUND_EMU10K1
#undef  CONFIG_MIDI_EMU10K1
#undef  CONFIG_SOUND_FUSION
#undef  CONFIG_SOUND_CS4281
#undef  CONFIG_SOUND_ES1370
#undef  CONFIG_SOUND_ES1371
#undef  CONFIG_SOUND_ESSSOLO1
#undef  CONFIG_SOUND_MAESTRO
#undef  CONFIG_SOUND_MAESTRO3
#undef  CONFIG_SOUND_FORTE
#undef  CONFIG_SOUND_ICH
#undef  CONFIG_SOUND_RME96XX
#undef  CONFIG_SOUND_SONICVIBES
#undef  CONFIG_SOUND_TRIDENT
#undef  CONFIG_SOUND_MSNDCLAS
#undef  CONFIG_SOUND_MSNDPIN
#undef  CONFIG_SOUND_VIA82CXXX
#undef  CONFIG_MIDI_VIA82CXXX
#define CONFIG_SOUND_OSS 1
#undef  CONFIG_SOUND_TRACEINIT
#undef  CONFIG_SOUND_DMAP
#undef  CONFIG_SOUND_AD1816
#undef  CONFIG_SOUND_AD1889
#undef  CONFIG_SOUND_SGALAXY
#undef  CONFIG_SOUND_ADLIB
#undef  CONFIG_SOUND_ACI_MIXER
#undef  CONFIG_SOUND_CS4232
#undef  CONFIG_SOUND_SSCAPE
#undef  CONFIG_SOUND_GUS
#undef  CONFIG_SOUND_VMIDI
#undef  CONFIG_SOUND_TRIX
#undef  CONFIG_SOUND_MSS
#undef  CONFIG_SOUND_MPU401
#undef  CONFIG_SOUND_NM256
#undef  CONFIG_SOUND_MAD16
#undef  CONFIG_SOUND_PAS
#undef  CONFIG_PAS_JOYSTICK
#undef  CONFIG_SOUND_PSS
#undef  CONFIG_SOUND_SB
#undef  CONFIG_SOUND_AWE32_SYNTH
#undef  CONFIG_SOUND_KAHLUA
#undef  CONFIG_SOUND_WAVEFRONT
#undef  CONFIG_SOUND_MAUI
#undef  CONFIG_SOUND_YM3812
#undef  CONFIG_SOUND_OPL3SA1
#undef  CONFIG_SOUND_OPL3SA2
#undef  CONFIG_SOUND_YMFPCI
#undef  CONFIG_SOUND_YMFPCI_LEGACY
#undef  CONFIG_SOUND_UART6850
#undef  CONFIG_SOUND_AEDSP16
#define CONFIG_SOUND_VIDC 1
#undef  CONFIG_SOUND_WAVEARTIST
#undef  CONFIG_SOUND_TVMIXER
#undef  CONFIG_SOUND_AD1980
#undef  CONFIG_SOUND_WM97XX

/*
 * Multimedia Capabilities Port drivers
 */
#undef  CONFIG_MCP
#undef  CONFIG_MCP_SA1100
#undef  CONFIG_MCP_UCB1200
#undef  CONFIG_MCP_UCB1200_AUDIO
#undef  CONFIG_MCP_UCB1200_TS

/*
 * USB support
 */
#undef  CONFIG_USB

/*
 * Support for USB gadgets
 */
#undef  CONFIG_USB_GADGET

/*
 * Bluetooth support
 */
#undef  CONFIG_BLUEZ

/*
 * Kernel hacking
 */
#define CONFIG_FRAME_POINTER 1
#undef  CONFIG_DEBUG_USER
#undef  CONFIG_DEBUG_INFO
#undef  CONFIG_NO_PGT_CACHE
#define CONFIG_DEBUG_KERNEL 1
#undef  CONFIG_DEBUG_SLAB
#undef  CONFIG_MAGIC_SYSRQ
#undef  CONFIG_DEBUG_SPINLOCK
#undef  CONFIG_DEBUG_WAITQ
#undef  CONFIG_DEBUG_BUGVERBOSE
#define CONFIG_DEBUG_ERRORS 1
#undef  CONFIG_DEBUG_LL
#undef  CONFIG_DEBUG_DC21285_PORT
#undef  CONFIG_DEBUG_CLPS711X_UART2

/*
 * Library routines
 */
#undef  CONFIG_CRC32
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_ZLIB_DEFLATE 1
