#define UTS_VERSION "#1 Thu Jul 1 08:46:41 Local time zone must be set--see zic manua"
#define LINUX_COMPILE_TIME "08:46:41"
#define LINUX_COMPILE_BY "root"
#define LINUX_COMPILE_HOST "stokely"
#define LINUX_COMPILE_DOMAIN "armedslack.org"
#define LINUX_COMPILER "gcc version 3.4.0"
